@@ -1,62 +1,6 @@
-__name__ = "socket_api2"
-__version__ = "0.1.1"
-
-__author__ = "Da4ndo"
-__discord__ = "Da4ndo#0934"
-__youtube__ = "https://www.youtube.com/channel/UCdhZa-JISiqwd913nhB8cAw?"
-__github__ = "https://github.com/Mesteri05"
-
 import socket
-from pyngrok import ngrok
-import _thread, threading, time
-
-class SEND_METHOD:
-    default_send = 0
-    just_send = 1
-
-def outstr(mode, text, start=""):
-    """
-    MODE = ["INFO", "DEBUG", "ERROR", "ACCESS"]
-    """
-
-    ct = time.localtime()
-    t = time.strftime("%Y.%m.%d %H:%M:%S", ct)
-
-    try:
-        import colorama
-        colorama.init()
-
-        red = colorama.Fore.RED
-        red2 = colorama.Fore.LIGHTRED_EX
-        blue = colorama.Fore.BLUE
-        blue2 = colorama.Fore.LIGHTBLUE_EX
-        green = colorama.Fore.GREEN
-        gray = colorama.Fore.LIGHTBLACK_EX
-        gray2 = colorama.Fore.LIGHTWHITE_EX
-        magenta = colorama.Fore.MAGENTA
-        reset = colorama.Fore.RESET
-
-        if mode.lower() == "info":
-            print(f"{start}[{t}]{reset} {blue}<{mode}>{reset}: {blue2}{text}{reset}")
-        elif mode.lower() == "debug":
-            print(f"{start}[{t}]{reset} {gray}<{mode}>{reset}: {gray2}{text}{reset}")
-        elif mode.lower() == "error":
-            print(f"{start}[{t}]{reset} {red}<{mode}>{reset}: {red2}{text}{reset}")
-        elif mode.lower() == "access":
-            print(f"{start}[{t}]{reset} {green}<INFO>{reset}: {green}{text}{reset}")
-        else:
-            raise Exception(f"Wrong mode. Valid modes are INFO, DEBUG, ERROR, ACCESS not {mode}")
-    except Exception as e:
-        if mode.lower() == "info":
-            print(f"{start}[{t}] <{mode}>: {text}")
-        elif mode.lower() == "debug":
-            print(f"{start}[{t}] <{mode}>: {text}")
-        elif mode.lower() == "error":
-            print(f"{start}[{t}] <{mode}>: {text}")
-        elif mode.lower() == "access":
-            print(f"{start}[{t}] <INFO>: {text}")
-        else:
-            raise Exception(f"Wrong mode. Valid modes are INFO, DEBUG, ERROR, ACCESS not {mode}")
+import time
+from .utils import *
 
 class Client():
     def  __init__(self, target_ip:str, target_port:int, console_output:bool=True, timeout:int=None, reconnect:bool=True):
@@ -80,9 +24,9 @@ class Client():
         try:
             self.client.connect((self.ip, self.port))
             if self.console_output: outstr("INFO", f"Connected to {self.ip}:{self.port}")
-            return 200
+            return 200, None
         except Exception as e:
-            return e, 500
+            return 500, e
 
     def _reconnect(self):
         try:
@@ -90,7 +34,9 @@ class Client():
             self.client.close()
             del self.client
             self.client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            self.connect()
+            resp, error = self.connect()
+            if resp != 200 or error: 
+                return False
             self.reconnect_counter = 0
             return True
         except:
@@ -116,7 +62,7 @@ class Client():
             else:
                 msg = str(msg).encode()
             
-            if self.console_output: outstr("DEBUG", f"Send: {msg}")
+            if self.console_output: outstr("DEBUG", f"Send: {msg.decode()}")
 
             self.check_connection()
 
@@ -131,17 +77,14 @@ class Client():
         
         try:
             _send(msg, method)
-            return 200
+            return 200, None
         except ConnectionResetError as e:
-            return e, 500
+            return 500, e
         except socket.timeout as e:
-            return e, 500
+            return 500, e
         except Exception:
             raise Exception
     
-    def sendfile(self, file, offset=0, count=None):
-        self.client.sendfile(file, offset, count)
-    
     def recv(self, buffer:int=2048):
         self.check_connection()
 
@@ -185,9 +128,9 @@ class Client():
         try:
             return _recv()
         except ConnectionResetError as e:
-            return e, 500
+            return 500, e
         except socket.timeout as e:
-            return e, 500
+            return 500, e
         except Exception:
             raise Exception
 
