@@ -1,63 +1,10 @@
-__name__ = "socket_api2"
-__version__ = "0.1.1"
-
-__author__ = "Da4ndo"
-__discord__ = "Da4ndo#0934"
-__youtube__ = "https://www.youtube.com/channel/UCdhZa-JISiqwd913nhB8cAw?"
-__github__ = "https://github.com/Mesteri05"
-
+import _thread
+import os
 import socket
+import threading
+import time
 from pyngrok import ngrok
-import _thread, threading, time
-
-class SEND_METHOD:
-    default_send = 0
-    just_send = 1
-
-def outstr(mode, text, start=""):
-    """
-    MODE = ["INFO", "DEBUG", "ERROR", "ACCESS"]
-    """
-
-    ct = time.localtime()
-    t = time.strftime("%Y.%m.%d %H:%M:%S", ct)
-
-    try:
-        import colorama
-        colorama.init()
-
-        red = colorama.Fore.RED
-        red2 = colorama.Fore.LIGHTRED_EX
-        blue = colorama.Fore.BLUE
-        blue2 = colorama.Fore.LIGHTBLUE_EX
-        green = colorama.Fore.GREEN
-        gray = colorama.Fore.LIGHTBLACK_EX
-        gray2 = colorama.Fore.LIGHTWHITE_EX
-        magenta = colorama.Fore.MAGENTA
-        reset = colorama.Fore.RESET
-
-        if mode.lower() == "info":
-            print(f"{start}[{t}]{reset} {blue}<{mode}>{reset}: {blue2}{text}{reset}")
-        elif mode.lower() == "debug":
-            print(f"{start}[{t}]{reset} {gray}<{mode}>{reset}: {gray2}{text}{reset}")
-        elif mode.lower() == "error":
-            print(f"{start}[{t}]{reset} {red}<{mode}>{reset}: {red2}{text}{reset}")
-        elif mode.lower() == "access":
-            print(f"{start}[{t}]{reset} {green}<INFO>{reset}: {green}{text}{reset}")
-        else:
-            raise Exception(f"Wrong mode. Valid modes are INFO, DEBUG, ERROR, ACCESS not {mode}")
-    except Exception as e:
-        if mode.lower() == "info":
-            print(f"{start}[{t}] <{mode}>: {text}")
-        elif mode.lower() == "debug":
-            print(f"{start}[{t}] <{mode}>: {text}")
-        elif mode.lower() == "error":
-            print(f"{start}[{t}] <{mode}>: {text}")
-        elif mode.lower() == "access":
-            print(f"{start}[{t}] <INFO>: {text}")
-        else:
-            raise Exception(f"Wrong mode. Valid modes are INFO, DEBUG, ERROR, ACCESS not {mode}")
-
+from .utils import *
 
 class _ClientOOP():
     def __init__(self, ip, conn, console_output:bool=True, **kwargs):
@@ -94,7 +41,7 @@ class _ClientOOP():
         self.check_connection()
 
         time.sleep(0.2)
-        def _send(msg ,method):
+        def _send(msg, method):
             if isinstance(msg, str):
                 msg = msg.encode()
             elif isinstance(msg, bytes):
@@ -102,7 +49,7 @@ class _ClientOOP():
             else:
                 msg = str(msg).encode()
 
-            if self.console_output: outstr("DEBUG", f"Send to {self.ip}: {msg}")
+            if self.console_output: outstr("DEBUG", f"Send to {self.ip}: {msg.decode()}")
 
             if method == 0:
                 self.conn.send(str(len(msg)).encode())
@@ -115,21 +62,21 @@ class _ClientOOP():
         
         try:
             _send(msg, method)
-            return 200
+            return 200, None
         except ConnectionAbortedError as e:
-            return e, 500
+            return 500, e
 
         except socket.timeout as e:
-            return e, 500
+            return 500, e
 
         except ConnectionResetError as e:
-            return e, 500
+            return 500, e
     
         except OSError as e:
-            return e, 500
+            return 500, e
     
         except WindowsError as e:
-            return e, 500
+            return 500, e
 
         except Exception as e:
             raise e
@@ -167,19 +114,19 @@ class _ClientOOP():
             return _recv(buffer)
 
         except ConnectionAbortedError as e:
-            return e, 500
+            return 500, e
 
         except ConnectionResetError as e:
-            return e, 500
+            return 500, e
     
         except OSError as e:
-            return e, 500
+            return 500, e
     
         except WindowsError as e:
-            return e, 500
+            return 500, e
 
         except socket.timeout as e:
-            return e, 500
+            return 500, e
 
         except Exception as e:
             raise e
@@ -234,13 +181,11 @@ class Server():
         client_timeout:int=None,
         timeout:int=None,
         use_pyngrok:bool = False,
-        pyngrok_options:dict = None
+        pyngrok_options:dict = {},
+        **kwargs
     ):
         self.use_pyngrok = use_pyngrok
-        if not None:
-            self.pyngrok_options = pyngrok_options
-        else: 
-            raise Exception("If use_pyngrok is true then pyngrok_options is a required argument. If you don't know what options are valid, heres and example: pyngrok_options={\"mode\": \"tcp\"}")
+        self.pyngrok_options = pyngrok_options
 
         if ip == "auto":
             self.IP = socket.gethostbyname(socket.gethostname()) 
@@ -275,26 +220,34 @@ class Server():
             if self.console_output: outstr("INFO", "Listening for incoming connections...")
         
         threading.Thread(target=self.check_clients).start()
+        threading.Thread(target=self._accept).start()
 
+        try:
+            while True:
+                time.sleep(1)
+        except KeyboardInterrupt:
+            for client in self.clients:
+                client.send("exit")
+
+            outstr("info", "KeyboardInterrupt. Exiting...")
+            os._exit(0)
+        
+    def _accept(self):
         while True:
-            try:
-                conn, addr = self.server.accept()
-                if self.console_output: outstr("ACCESS", f"Connection from {addr} has been established!", start="\n")
+            conn, addr = self.server.accept()
+            if self.console_output: outstr("ACCESS", f"Connection from {addr} has been established!", start="\n")
 
-                new_client = _ClientOOP(ip=addr, conn=conn, console_output=self.console_output, timeout=self.client_timeout)
-                self.clients.append(new_client)
+            new_client = _ClientOOP(ip=addr, conn=conn, console_output=self.console_output, timeout=self.client_timeout)
+            self.clients.append(new_client)
 
-                for func in self.decorator_functions_call:
-                    _thread.start_new_thread(func, (new_client,))
-
-            except Exception:
-                raise Exception
+            for func in self.decorator_functions_call:
+                _thread.start_new_thread(func, (new_client,))
     
     def check_clients(self):
         def _check(client):
             if not client.check_connection():
                 self.clients.remove(client)
-                if self.console_output: outstr("DEBUG", f"{client.ip} is no longer connected. (Disconnect)")
+                if self.console_output: outstr("DEBUG", f"{client.ip} is no longer connected.")
                 for func in self.decorator_client_disconnect:
                     _thread.start_new_thread(func, (client,))
 
@@ -339,4 +292,4 @@ class Server():
                 self.decorator_client_disconnect.append(func)
             return func
 
-        return decorator
\ No newline at end of file
+        return decorator
